/*
 * @package netNotes
 * @author Sebastian Tschan
 * @copyright (c) Sebastian Tschan
 * @license GNU General Public License
 * @link https://blueimp.net/mozilla/
 */

var NotesBox = {

	LocationManager: null,
	Notes: null,
	Utils:null,
	netNotes: null,
	netNotesPrefs: null,
	textboxID: 'notesBox',
	_textbox: null,
	_notes: null,
	_defaultURI: null,
	_currentURI: null,
	_noteBuffer: null,
	
	initialize: function() {	
		const Cc = Components.classes;
		const Ci = Components.interfaces;
		const Cu = Components.utils;
		// Load the LocationManager, the Notes Class and the Utils into the scope of this object:
		Cu.import('resource://netNotes/location.js', this);
		Cu.import('resource://netNotes/notes.js', this);
		Cu.import('resource://netNotes/utils.js', this);
		
		// Retrieve the netNotes extension object and its preferences object:
		this.netNotes = Application.extensions.get('netNotes@blueimp.net');
		this.netNotesPrefs = this.netNotes.prefs;
		// Retrieve a second extension object as FUEL doesn't provide access to complex prefs:
		this.netNotesPrefs2 = Cc['@mozilla.org/preferences-service;1']
								.getService(Ci.nsIPrefService)
								.getBranch('extensions.netNotes@blueimp.net.');
								
		// Initialize a Notes object with the netNotes preferences:
		this._notes = new this.Notes(
			this.netNotesPrefs.get('bookmarksFolderID').value,
			this.netNotesPrefs2.getComplexValue('pageNoteTags',Ci.nsIPrefLocalizedString).data.split(',')
		);
		this._defaultURI = this.Utils.createURI('about:blank', 'UTF-8');		
		this._textbox = document.getElementById(this.textboxID);
		
		// Enable/disable spell checking:
		this._textbox.setAttribute(
			'spellcheck',
			this.netNotesPrefs.get('spellcheck').value
		);
		
		// Add a listener to the _textbox to update the _noteBuffer on input events:
		this._textbox.addEventListener(
			'input',
			this._updateNoteBuffer,
			false
		);
		// Listen to Location changes and load the current Note:
		this.LocationManager.addListener(this._loadNote);
		this._loadNote(this.Utils.getCurrentURI());
		
		// Set the focus to the _textbox:
		this._textbox.focus();
	},

	finalize: function() {
		// Save the changed note content when closing the Notes window:
		if(NotesBox._noteBuffer !== null) {
			NotesBox._saveNote();
		}
		// Remove the listener from the _textbox:
		this._textbox.removeEventListener(
			'input',
			this._updateNoteBuffer,
			false
		);
		try{
			// Return the focus to the browser contentWindow:
			this.Utils.getBrowser().contentWindow.focus();
			this.LocationManager.removeListener(this._loadNote);
		}catch(e){
			// The main browser window has been closed before
			// the focus could be returned or the listener could be removed.
		}
	},
	
	_loadNote: function(uri) {
		// the value of "this" is changed when called via LocationManager events,
		// so we have to directly reference the "NotesBox" object instead:
		
		// Save the changed note content when loading a new note:
		if(NotesBox._noteBuffer !== null) {
			NotesBox._saveNote();
		}	
		// If no uri is given load the _defaultURI:
		NotesBox._currentURI = uri ? uri : NotesBox._defaultURI;
		NotesBox._textbox.value = NotesBox._notes.getPageNote(NotesBox._currentURI);
	},

	_updateNoteBuffer: function() {
		// the value of "this" is changed when called via _textbox input events,
		// so we have to directly reference the "NotesBox" object instead:
		NotesBox._noteBuffer = NotesBox._textbox.value;
	},
	
	_saveNote: function() {
		this._notes.setPageNote(
			this._currentURI,
			this._noteBuffer
		);
		this._noteBuffer = null;
	}
	
}