/*
 * @package netNotes
 * @author Sebastian Tschan
 * @copyright (c) Sebastian Tschan
 * @license GNU General Public License
 * @link https://blueimp.net/mozilla/
 */

var netNotes = Application.extensions.get('netNotes@blueimp.net');

function toggleNetNotesBottomBar() {
	var splitter = document.getElementById('netNotesBottomBarSplitter');
	var box = document.getElementById('netNotesBottomBarBox');
	var bar = document.getElementById('netNotesBottomBar');	
	if(!box.hidden) {
		bar.setAttribute('src', 'about:blank');
		box.hidden = true;
		splitter.hidden = true;
		return;
	}
	box.hidden = false;
	splitter.hidden = false;
	var url = document.getElementById('viewNetNotesSidebar').getAttribute('sidebarurl');
	bar.setAttribute('src', url);
}

function updateNetNotesViewCommand() {
	var viewNetNotes = document.getElementById('viewNetNotes');
	viewNetNotes.setAttribute(
		'command',
		netNotes.prefs.get('notesView').value
	);
}

function updateNetNotesKeyboardShortcut() {
	var netNotesKey = document.getElementById('netNotesKey');
	if(netNotesKey) {
		const Cc = Components.classes;
		const Ci = Components.interfaces;
		var netNotesPrefs2 = Cc['@mozilla.org/preferences-service;1']
									.getService(Ci.nsIPrefService)
									.getBranch('extensions.netNotes@blueimp.net.');
		var items = netNotesPrefs2
					.getComplexValue('keyboardShortcut',Ci.nsIPrefLocalizedString)
					.data.split('+');
		if(items[0]) {
			// Remove the last element and save it as key:
			var key = items.pop();
			// Check if the key is a keycode:
			if(key.indexOf('VK') == 0) {
				netNotesKey.removeAttribute('key');
				netNotesKey.setAttribute('keycode',key);
			} else {
				netNotesKey.removeAttribute('keycode');
				netNotesKey.setAttribute('key',key);
			}
			// The remaining items are the modifiers:
			if(!items.length) {
				netNotesKey.removeAttribute('modifiers');
			} else {
				netNotesKey.setAttribute('modifiers',items.join(' '));
			}
		} else {
			netNotesKey.removeAttribute('key');
			netNotesKey.removeAttribute('keycode');
			netNotesKey.removeAttribute('modifiers');
		}
	}
}

function initializeNetNotes() {
	netNotes.prefs.get('notesView').events.addListener(
		'change',
		updateNetNotesViewCommand
	);
	netNotes.prefs.get('keyboardShortcut').events.addListener(
		'change',
		updateNetNotesViewCommand
	);
	updateNetNotesViewCommand();
	updateNetNotesKeyboardShortcut();
}

function finalizeNetNotes() {
	netNotes.prefs.get('notesView').events.removeListener(
		'change',
		updateNetNotesViewCommand
	);
	netNotes.prefs.get('keyboardShortcut').events.removeListener(
		'change',
		updateNetNotesViewCommand
	);
}

window.addEventListener('load', initializeNetNotes, false);
window.addEventListener('unload', finalizeNetNotes, false);